==> request-tracker4_4.4.4+dfsg.orig-third-party-source.tar.gz: rt-4.4.4/devel/third-party/ckeditor-src/plugins/specialchar/dialogs/lang/pl.js <==
﻿/**
 * @license Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or http://ckeditor.com/license
 */

CKEDITOR.plugins.setLang( 'specialchar', 'pl', {
	euro: 'Znak euro',
	lsquo: 'Cudzysłów pojedynczy otwierający',
	rsquo: 'Cudzysłów pojedynczy zamykający',
	ldquo: 'Cudzysłów apostrofowy otwierający',
	rdquo: 'Cudzysłów apostrofowy zamykający',
	ndash: 'Półpauza',
	mdash: 'Pauza',
	iexcl: 'Odwrócony wykrzyknik',
	cent: 'Znak centa',
	pound: 'Znak funta',
	curren: 'Znak waluty',
	yen: 'Znak jena',
	brvbar: 'Przerwana pionowa kreska',
	sect: 'Paragraf',
	uml: 'Diereza',
	copy: 'Znak praw autorskich',
	ordf: 'Wskaźnik rodzaju żeńskiego liczebnika porządkowego',
	laquo: 'Lewy cudzysłów ostrokątny',
	not: 'Znak negacji',
	reg: 'Zastrzeżony znak towarowy',
	macr: 'Makron',
	deg: 'Znak stopnia',
	sup2: 'Druga potęga',
	sup3: 'Trzecia potęga',
	acute: 'Akcent ostry',
	micro: 'Znak mikro',
	para: 'Znak akapitu',
	middot: 'Kropka środkowa',
	cedil: 'Cedylla',
	sup1: 'Pierwsza potęga',
	ordm: 'Wskaźnik rodzaju męskiego liczebnika porządkowego',
	raquo: 'Prawy cudzysłów ostrokątny',
	frac14: 'Ułamek zwykły jedna czwarta',
	frac12: 'Ułamek zwykły jedna druga',
	frac34: 'Ułamek zwykły trzy czwarte',
	iquest: 'Odwrócony znak zapytania',
	Agrave: 'Wielka litera A z akcentem ciężkim',
	Aacute: 'Wielka litera A z akcentem ostrym',
	Acirc: 'Wielka litera A z akcentem przeciągłym',
	Atilde: 'Wielka litera A z tyldą',
	Auml: 'Wielka litera A z dierezą',
	Aring: 'Wielka litera A z kółkiem',
	AElig: 'Wielka ligatura Æ',
	Ccedil: 'Wielka litera C z cedyllą',
	Egrave: 'Wielka litera E z akcentem ciężkim',
	Eacute: 'Wielka litera E z akcentem ostrym',
	Ecirc: 'Wielka litera E z akcentem przeciągłym',
	Euml: 'Wielka litera E z dierezą',
	Igrave: 'Wielka litera I z akcentem ciężkim',
	Iacute: 'Wielka litera I z akcentem ostrym',
	Icirc: 'Wielka litera I z akcentem przeciągłym',
	Iuml: 'Wielka litera I z dierezą',
	ETH: 'Wielka litera Eth',
	Ntilde: 'Wielka litera N z tyldą',
	Ograve: 'Wielka litera O z akcentem ciężkim',
	Oacute: 'Wielka litera O z akcentem ostrym',
	Ocirc: 'Wielka litera O z akcentem przeciągłym',
	Otilde: 'Wielka litera O z tyldą',
	Ouml: 'Wielka litera O z dierezą',
	times: 'Znak mnożenia wektorowego',
	Oslash: 'Wielka litera O z przekreśleniem',
	Ugrave: 'Wielka litera U z akcentem ciężkim',
	Uacute: 'Wielka litera U z akcentem ostrym',
	Ucirc: 'Wielka litera U z akcentem przeciągłym',
	Uuml: 'Wielka litera U z dierezą',
	Yacute: 'Wielka litera Y z akcentem ostrym',
	THORN: 'Wielka litera Thorn',
	szlig: 'Mała litera ostre s (eszet)',
	agrave: 'Mała litera a z akcentem ciężkim',
	aacute: 'Mała litera a z akcentem ostrym',
	acirc: 'Mała litera a z akcentem przeciągłym',
	atilde: 'Mała litera a z tyldą',
	auml: 'Mała litera a z dierezą',
	aring: 'Mała litera a z kółkiem',
	aelig: 'Mała ligatura æ',
	ccedil: 'Mała litera c z cedyllą',
	egrave: 'Mała litera e z akcentem ciężkim',
	eacute: 'Mała litera e z akcentem ostrym',
	ecirc: 'Mała litera e z akcentem przeciągłym',
	euml: 'Mała litera e z dierezą',
	igrave: 'Mała litera i z akcentem ciężkim',
	iacute: 'Mała litera i z akcentem ostrym',
	icirc: 'Mała litera i z akcentem przeciągłym',
	iuml: 'Mała litera i z dierezą',
	eth: 'Mała litera eth',
	ntilde: 'Mała litera n z tyldą',
	ograve: 'Mała litera o z akcentem ciężkim',
	oacute: 'Mała litera o z akcentem ostrym',
	ocirc: 'Mała litera o z akcentem przeciągłym',
	otilde: 'Mała litera o z tyldą',
	ouml: 'Mała litera o z dierezą',
	divide: 'Anglosaski znak dzielenia',
	oslash: 'Mała litera o z przekreśleniem',
	ugrave: 'Mała litera u z akcentem ciężkim',
	uacute: 'Mała litera u z akcentem ostrym',
	ucirc: 'Mała litera u z akcentem przeciągłym',
	uuml: 'Mała litera u z dierezą',
	yacute: 'Mała litera y z akcentem ostrym',
	thorn: 'Mała litera thorn',
	yuml: 'Mała litera y z dierezą',
	OElig: 'Wielka ligatura OE',
	oelig: 'Mała ligatura oe',
	'372': 'Wielka litera W z akcentem przeciągłym',
	'374': 'Wielka litera Y z akcentem przeciągłym',
	'373': 'Mała litera w z akcentem przeciągłym',
	'375': 'Mała litera y z akcentem przeciągłym',
	sbquo: 'Pojedynczy apostrof dolny',
	'8219': 'Pojedynczy apostrof górny',
	bdquo: 'Podwójny apostrof dolny',
	hellip: 'Wielokropek',
	trade: 'Znak towarowy',
	'9658': 'Czarny wskaźnik wskazujący w prawo',
	bull: 'Punktor',
	rarr: 'Strzałka w prawo',
	rArr: 'Podwójna strzałka w prawo',
	hArr: 'Podwójna strzałka w lewo',
	diams: 'Czarny znak karo',
	asymp: 'Znak prawie równe'
} );

==> request-tracker5_5.0.1+dfsg.orig-third-party-source.tar.gz: rt-5.0.1/devel/third-party/ckeditor-src/plugins/specialchar/dialogs/lang/pl.js <==
/**
 * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

CKEDITOR.plugins.setLang( 'specialchar', 'pl', {
	euro: 'Znak euro',
	lsquo: 'Cudzysłów pojedynczy otwierający',
	rsquo: 'Cudzysłów pojedynczy zamykający',
	ldquo: 'Cudzysłów apostrofowy otwierający',
	rdquo: 'Cudzysłów apostrofowy zamykający',
	ndash: 'Półpauza',
	mdash: 'Pauza',
	iexcl: 'Odwrócony wykrzyknik',
	cent: 'Znak centa',
	pound: 'Znak funta',
	curren: 'Znak waluty',
	yen: 'Znak jena',
	brvbar: 'Przerwana pionowa kreska',
	sect: 'Paragraf',
	uml: 'Diereza',
	copy: 'Znak praw autorskich',
	ordf: 'Wskaźnik rodzaju żeńskiego liczebnika porządkowego',
	laquo: 'Lewy cudzysłów ostrokątny',
	not: 'Znak negacji',
	reg: 'Zastrzeżony znak towarowy',
	macr: 'Makron',
	deg: 'Znak stopnia',
	sup2: 'Druga potęga',
	sup3: 'Trzecia potęga',
	acute: 'Akcent ostry',
	micro: 'Znak mikro',
	para: 'Znak akapitu',
	middot: 'Kropka środkowa',
	cedil: 'Cedylla',
	sup1: 'Pierwsza potęga',
	ordm: 'Wskaźnik rodzaju męskiego liczebnika porządkowego',
	raquo: 'Prawy cudzysłów ostrokątny',
	frac14: 'Ułamek zwykły jedna czwarta',
	frac12: 'Ułamek zwykły jedna druga',
	frac34: 'Ułamek zwykły trzy czwarte',
	iquest: 'Odwrócony znak zapytania',
	Agrave: 'Wielka litera A z akcentem ciężkim',
	Aacute: 'Wielka litera A z akcentem ostrym',
	Acirc: 'Wielka litera A z akcentem przeciągłym',
	Atilde: 'Wielka litera A z tyldą',
	Auml: 'Wielka litera A z dierezą',
	Aring: 'Wielka litera A z kółkiem',
	AElig: 'Wielka ligatura Æ',
	Ccedil: 'Wielka litera C z cedyllą',
	Egrave: 'Wielka litera E z akcentem ciężkim',
	Eacute: 'Wielka litera E z akcentem ostrym',
	Ecirc: 'Wielka litera E z akcentem przeciągłym',
	Euml: 'Wielka litera E z dierezą',
	Igrave: 'Wielka litera I z akcentem ciężkim',
	Iacute: 'Wielka litera I z akcentem ostrym',
	Icirc: 'Wielka litera I z akcentem przeciągłym',
	Iuml: 'Wielka litera I z dierezą',
	ETH: 'Wielka litera Eth',
	Ntilde: 'Wielka litera N z tyldą',
	Ograve: 'Wielka litera O z akcentem ciężkim',
	Oacute: 'Wielka litera O z akcentem ostrym',
	Ocirc: 'Wielka litera O z akcentem przeciągłym',
	Otilde: 'Wielka litera O z tyldą',
	Ouml: 'Wielka litera O z dierezą',
	times: 'Znak mnożenia wektorowego',
	Oslash: 'Wielka litera O z przekreśleniem',
	Ugrave: 'Wielka litera U z akcentem ciężkim',
	Uacute: 'Wielka litera U z akcentem ostrym',
	Ucirc: 'Wielka litera U z akcentem przeciągłym',
	Uuml: 'Wielka litera U z dierezą',
	Yacute: 'Wielka litera Y z akcentem ostrym',
	THORN: 'Wielka litera Thorn',
	szlig: 'Mała litera ostre s (eszet)',
	agrave: 'Mała litera a z akcentem ciężkim',
	aacute: 'Mała litera a z akcentem ostrym',
	acirc: 'Mała litera a z akcentem przeciągłym',
	atilde: 'Mała litera a z tyldą',
	auml: 'Mała litera a z dierezą',
	aring: 'Mała litera a z kółkiem',
	aelig: 'Mała ligatura æ',
	ccedil: 'Mała litera c z cedyllą',
	egrave: 'Mała litera e z akcentem ciężkim',
	eacute: 'Mała litera e z akcentem ostrym',
	ecirc: 'Mała litera e z akcentem przeciągłym',
	euml: 'Mała litera e z dierezą',
	igrave: 'Mała litera i z akcentem ciężkim',
	iacute: 'Mała litera i z akcentem ostrym',
	icirc: 'Mała litera i z akcentem przeciągłym',
	iuml: 'Mała litera i z dierezą',
	eth: 'Mała litera eth',
	ntilde: 'Mała litera n z tyldą',
	ograve: 'Mała litera o z akcentem ciężkim',
	oacute: 'Mała litera o z akcentem ostrym',
	ocirc: 'Mała litera o z akcentem przeciągłym',
	otilde: 'Mała litera o z tyldą',
	ouml: 'Mała litera o z dierezą',
	divide: 'Anglosaski znak dzielenia',
	oslash: 'Mała litera o z przekreśleniem',
	ugrave: 'Mała litera u z akcentem ciężkim',
	uacute: 'Mała litera u z akcentem ostrym',
	ucirc: 'Mała litera u z akcentem przeciągłym',
	uuml: 'Mała litera u z dierezą',
	yacute: 'Mała litera y z akcentem ostrym',
	thorn: 'Mała litera thorn',
	yuml: 'Mała litera y z dierezą',
	OElig: 'Wielka ligatura OE',
	oelig: 'Mała ligatura oe',
	'372': 'Wielka litera W z akcentem przeciągłym',
	'374': 'Wielka litera Y z akcentem przeciągłym',
	'373': 'Mała litera w z akcentem przeciągłym',
	'375': 'Mała litera y z akcentem przeciągłym',
	sbquo: 'Pojedynczy apostrof dolny',
	'8219': 'Pojedynczy apostrof górny',
	bdquo: 'Podwójny apostrof dolny',
	hellip: 'Wielokropek',
	trade: 'Znak towarowy',
	'9658': 'Czarny wskaźnik wskazujący w prawo',
	bull: 'Punktor',
	rarr: 'Strzałka w prawo',
	rArr: 'Podwójna strzałka w prawo',
	hArr: 'Podwójna strzałka obustronna',
	diams: 'Czarny znak karo',
	asymp: 'Znak prawie równe'
} );
